function [Tc1c2F] = translOp(F, sampling, c1, c2, kappa)
% Applies generalized far field translation operator on F
%   INPUT: c1 - shift vector for row space, 2x1 array.
%          c2 - shift vector for column space, 2x1 array.
%          kappa - wave number.
%          F - farfield matrix.
%          sampling - structure that contains information about the
%                     discretization.
%   OUTPUT Tc1c2F - translated far field matrix.

xhat = sampling.xhat;
d = sampling.d.';

Tc1 = diag(exp(1i*kappa*[cos(xhat), sin(xhat)]*c1));
Tc2 = diag(exp(1i*kappa*[cos(d), sin(d)]*c2));
Tc1c2F = Tc1*F*Tc2';

end